@@ -26,6 +26,9 @@ FAILEDOPERATION_CREATECLUSTER = 'FailedOperation.CreateCluster'
 # 环境创建失败。
 FAILEDOPERATION_CREATEENVIRONMENT = 'FailedOperation.CreateEnvironment'
 
+# 创建环境角色失败。
+FAILEDOPERATION_CREATEENVIRONMENTROLE = 'FailedOperation.CreateEnvironmentRole'
+
 # 创建命名空间失败。
 FAILEDOPERATION_CREATENAMESPACE = 'FailedOperation.CreateNamespace'
 
@@ -35,6 +38,12 @@ FAILEDOPERATION_CREATEPRODUCERERROR = 'FailedOperation.CreateProducerError'
 # 创建TDMQ client的出错。
 FAILEDOPERATION_CREATEPULSARCLIENTERROR = 'FailedOperation.CreatePulsarClientError'
 
+# 角色创建失败。
+FAILEDOPERATION_CREATEROLE = 'FailedOperation.CreateRole'
+
+# 创建秘钥失败。
+FAILEDOPERATION_CREATESECRETKEY = 'FailedOperation.CreateSecretKey'
+
 # 创建订阅关系失败。
 FAILEDOPERATION_CREATESUBSCRIPTION = 'FailedOperation.CreateSubscription'
 
@@ -44,12 +53,18 @@ FAILEDOPERATION_CREATETOPIC = 'FailedOperation.CreateTopic'
 # 删除集群失败。
 FAILEDOPERATION_DELETECLUSTER = 'FailedOperation.DeleteCluster'
 
+# 删除环境角色失败。
+FAILEDOPERATION_DELETEENVIRONMENTROLES = 'FailedOperation.DeleteEnvironmentRoles'
+
 # 环境删除失败。
 FAILEDOPERATION_DELETEENVIRONMENTS = 'FailedOperation.DeleteEnvironments'
 
 # 删除命名空间失败。
 FAILEDOPERATION_DELETENAMESPACE = 'FailedOperation.DeleteNamespace'
 
+# 角色删除失败。
+FAILEDOPERATION_DELETEROLES = 'FailedOperation.DeleteRoles'
+
 # 删除订阅关系失败。
 FAILEDOPERATION_DELETESUBSCRIPTIONS = 'FailedOperation.DeleteSubscriptions'
 
@@ -68,6 +83,12 @@ FAILEDOPERATION_GETENVIRONMENTATTRIBUTESFAILED = 'FailedOperation.GetEnvironment
 # 获取主题分区数失败。
 FAILEDOPERATION_GETTOPICPARTITIONSFAILED = 'FailedOperation.GetTopicPartitionsFailed'
 
+# 最大消息超过1MB。
+FAILEDOPERATION_MAXMESSAGESIZEERROR = 'FailedOperation.MaxMessageSizeError'
+
+# 上传的msgID错误。
+FAILEDOPERATION_MESSAGEIDERROR = 'FailedOperation.MessageIDError'
+
 # 必须先清除关联命名空间才能继续操作。
 FAILEDOPERATION_NAMESPACEINUSE = 'FailedOperation.NamespaceInUse'
 
@@ -83,6 +104,12 @@ FAILEDOPERATION_RESETMSGSUBOFFSETBYTIMESTAMPFAILED = 'FailedOperation.ResetMsgSu
 # 必须先清除关联角色数据才能继续操作。
 FAILEDOPERATION_ROLEINUSE = 'FailedOperation.RoleInUse'
 
+# 保存秘钥失败。
+FAILEDOPERATION_SAVESECRETKEY = 'FailedOperation.SaveSecretKey'
+
+# 消息发送超时。
+FAILEDOPERATION_SENDMESSAGETIMEOUTERROR = 'FailedOperation.SendMessageTimeoutError'
+
 # 发送消息失败。
 FAILEDOPERATION_SENDMSGFAILED = 'FailedOperation.SendMsgFailed'
 
@@ -92,15 +119,27 @@ FAILEDOPERATION_SETTTL = 'FailedOperation.SetTTL'
 # 必须先清除关联主题数据才能继续操作。
 FAILEDOPERATION_TOPICINUSE = 'FailedOperation.TopicInUse'
 
+# 请使用partition topic。
+FAILEDOPERATION_TOPICTYPEERROR = 'FailedOperation.TopicTypeError'
+
 # 环境更新失败。
 FAILEDOPERATION_UPDATEENVIRONMENT = 'FailedOperation.UpdateEnvironment'
 
+# 更新环境角色失败。
+FAILEDOPERATION_UPDATEENVIRONMENTROLE = 'FailedOperation.UpdateEnvironmentRole'
+
+# 角色更新失败。
+FAILEDOPERATION_UPDATEROLE = 'FailedOperation.UpdateRole'
+
 # 主题更新失败。
 FAILEDOPERATION_UPDATETOPIC = 'FailedOperation.UpdateTopic'
 
 # 必须先清除关联VPC路由数据才能继续操作。
 FAILEDOPERATION_VPCINUSE = 'FailedOperation.VpcInUse'
 
+# 内部错误。
+INTERNALERROR = 'InternalError'
+
 # Broker服务异常。
 INTERNALERROR_BROKERSERVICE = 'InternalError.BrokerService'
 
@@ -140,6 +179,9 @@ INVALIDPARAMETERVALUE_TTL = 'InvalidParameterValue.TTL'
 # 上传的topic name错误。
 INVALIDPARAMETERVALUE_TOPICNOTFOUND = 'InvalidParameterValue.TopicNotFound'
 
+# 超过配额限制。
+LIMITEXCEEDED = 'LimitExceeded'
+
 # 实例下集群数量超过限制。
 LIMITEXCEEDED_CLUSTERS = 'LimitExceeded.Clusters'
 
@@ -155,6 +197,9 @@ LIMITEXCEEDED_SUBSCRIPTIONS = 'LimitExceeded.Subscriptions'
 # 实例下主题数量超过限制。
 LIMITEXCEEDED_TOPICS = 'LimitExceeded.Topics'
 
+# 缺少参数错误。
+MISSINGPARAMETER = 'MissingParameter'
+
 # 必要参数没有传递。
 MISSINGPARAMETER_NEEDMOREPARAMS = 'MissingParameter.NeedMoreParams'
 
@@ -164,18 +209,33 @@ OPERATIONDENIED_CONSUMERRUNNING = 'OperationDenied.ConsumerRunning'
 # 默认环境不允许操作。
 OPERATIONDENIED_DEFAULTENVIRONMENT = 'OperationDenied.DefaultEnvironment'
 
+# 资源被占用。
+RESOURCEINUSE = 'ResourceInUse'
+
 # 集群已存在。
 RESOURCEINUSE_CLUSTER = 'ResourceInUse.Cluster'
 
+# 环境角色已存在。
+RESOURCEINUSE_ENVIRONMENTROLE = 'ResourceInUse.EnvironmentRole'
+
 # 重名，命名空间已存在。
 RESOURCEINUSE_NAMESPACE = 'ResourceInUse.Namespace'
 
+# 角色已存在。
+RESOURCEINUSE_ROLE = 'ResourceInUse.Role'
+
 # 重名，订阅关系已存在。
 RESOURCEINUSE_SUBSCRIPTION = 'ResourceInUse.Subscription'
 
 # 重名，主题已存在。
 RESOURCEINUSE_TOPIC = 'ResourceInUse.Topic'
 
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
+# 资源不存在。
+RESOURCENOTFOUND = 'ResourceNotFound'
+
 # 服务的集群不存在。
 RESOURCENOTFOUND_BROKERCLUSTER = 'ResourceNotFound.BrokerCluster'
 
@@ -185,6 +245,9 @@ RESOURCENOTFOUND_CLUSTER = 'ResourceNotFound.Cluster'
 # 环境不存在。
 RESOURCENOTFOUND_ENVIRONMENT = 'ResourceNotFound.Environment'
 
+# 环境角色不存在。
+RESOURCENOTFOUND_ENVIRONMENTROLE = 'ResourceNotFound.EnvironmentRole'
+
 # 命名空间不存在。
 RESOURCENOTFOUND_NAMESPACE = 'ResourceNotFound.Namespace'
 
